@@ -30,18 +30,6 @@ def start(args):
         helpers.lxc.start(args)
 
     def upgrade(system_zip, system_time, vendor_zip, vendor_time):
-        if os.path.exists(system_zip):
-            if not helpers.images.validate(args, "system_ota", system_zip):
-                logging.warning("Not upgrading because system.img comes from an unverified source")
-                return
-        else:
-            system_zip = "" # Race prevention
-        if os.path.exists(vendor_zip):
-            if not helpers.images.validate(args, "vendor_ota", vendor_zip):
-                logging.warning("Not upgrading because vendor.img comes from an unverified source")
-                return
-        else:
-            vendor_zip = "" # Race prevention
         helpers.lxc.stop(args)
         helpers.images.umount_rootfs(args)
         helpers.images.replace(args, system_zip, system_time,
